#' Class \code{"TLum"}
#'
#' Abstract class for data in the package Luminescence
#'
#' @name TLum-class
#' @rdname TLum-class
#'
#' @note \code{TLum} is a virtual class.
#'
#' @keywords classes
#'
#' @author David Strebler
#'
#' @exportClass TLum

setClass(Class = "TLum")
